==> xkaapi-2.1.tar.gz: xkaapi-2.1/src/machine/cuda/kaapi_cuda_task_steal_body.c <==
/*
 ** xkaapi
 **
 ** Copyright 2009,2010,2011,2012 INRIA.
 **
 ** Contributors :
 **
 ** thierry.gautier@inrialpes.fr
 ** Joao.Lima@imagf.r / joao.lima@inf.ufrgs.br
 **
 ** This software is a computer program whose purpose is to execute
 ** multithreaded computation with data flow synchronization between
 ** threads.
 **
 ** This software is governed by the CeCILL-C license under French law
 ** and abiding by the rules of distribution of free software.  You can
 ** use, modify and/ or redistribute the software under the terms of
 ** the CeCILL-C license as circulated by CEA, CNRS and INRIA at the
 ** following URL "http://www.cecill.info".
 **
 ** As a counterpart to the access to the source code and rights to
 ** copy, modify and redistribute granted by the license, users are
 ** provided only with a limited warranty and the software's author,
 ** the holder of the economic rights, and the successive licensors
 ** have only limited liability.
 **
 ** In this respect, the user's attention is drawn to the risks
 ** associated with loading, using, modifying and/or developing or
 ** reproducing the software by the user in light of its specific
 ** status of free software, that may mean that it is complicated to
 ** manipulate, and that also therefore means that it is reserved for
 ** developers and experienced professionals having in-depth computer
 ** knowledge. Users are therefore encouraged to load and test the
 ** software's suitability as regards their requirements in conditions
 ** enabling the security of their systems and/or data to be ensured
 ** and, more generally, to use and operate it in the same conditions
 ** as regards security.
 **
 ** The fact that you are presently reading this means that you have
 ** had knowledge of the CeCILL-C license and that you accept its
 ** terms.
 **
 */

#include <stdio.h>

#include <cuda_runtime_api.h>

#include "kaapi_impl.h"
#include "kaapi_cuda_impl.h"

/* cuda task body */
typedef void (*kaapi_cuda_task_body_t) (void *, cudaStream_t);

int kaapi_cuda_task_steal_body(kaapi_thread_t* thread, const kaapi_format_t * fmt, void *sp)
{
  /* TODO changer kaapi_format_get_task_bodywh_by_arch */
  kaapi_cuda_task_body_t body = (kaapi_cuda_task_body_t)kaapi_format_get_task_body_by_arch(fmt, KAAPI_PROC_TYPE_CUDA);
  kaapi_assert_debug(body != 0);
  kaapi_cuda_ctx_push();
  body(sp, kaapi_cuda_kernel_stream());
  kaapi_cuda_ctx_pop();
 
  return 0;
}

==> xkaapi-2.2.tar.gz: xkaapi-2.2/src/machine/cuda/kaapi_cuda_task_steal_body.c <==
/*
 ** xkaapi
 **
 ** Copyright 2009,2010,2011,2012 INRIA.
 **
 ** Contributors :
 **
 ** thierry.gautier@inrialpes.fr
 ** Joao.Lima@imagf.r / joao.lima@inf.ufrgs.br
 **
 ** This software is a computer program whose purpose is to execute
 ** multithreaded computation with data flow synchronization between
 ** threads.
 **
 ** This software is governed by the CeCILL-C license under French law
 ** and abiding by the rules of distribution of free software.  You can
 ** use, modify and/ or redistribute the software under the terms of
 ** the CeCILL-C license as circulated by CEA, CNRS and INRIA at the
 ** following URL "http://www.cecill.info".
 **
 ** As a counterpart to the access to the source code and rights to
 ** copy, modify and redistribute granted by the license, users are
 ** provided only with a limited warranty and the software's author,
 ** the holder of the economic rights, and the successive licensors
 ** have only limited liability.
 **
 ** In this respect, the user's attention is drawn to the risks
 ** associated with loading, using, modifying and/or developing or
 ** reproducing the software by the user in light of its specific
 ** status of free software, that may mean that it is complicated to
 ** manipulate, and that also therefore means that it is reserved for
 ** developers and experienced professionals having in-depth computer
 ** knowledge. Users are therefore encouraged to load and test the
 ** software's suitability as regards their requirements in conditions
 ** enabling the security of their systems and/or data to be ensured
 ** and, more generally, to use and operate it in the same conditions
 ** as regards security.
 **
 ** The fact that you are presently reading this means that you have
 ** had knowledge of the CeCILL-C license and that you accept its
 ** terms.
 **
 */

#include <stdio.h>

#include <cuda_runtime_api.h>

#include "kaapi_impl.h"
#include "kaapi_cuda_impl.h"

/* cuda task body */
typedef void (*kaapi_cuda_task_body_t) (void *, cudaStream_t);

int kaapi_cuda_task_steal_body(kaapi_thread_t* thread, const kaapi_format_t * fmt, void *sp)
{
  /* TODO change kaapi_format_get_task_bodywh_by_arch */
  fprintf(stdout, "%d:%s: format=%s sp=%p\n", kaapi_get_self_kid(), __FUNCTION__,
          fmt->name, sp);
  fflush(stdout);
  kaapi_cuda_ctx_push();
  cudaStreamSynchronize(kaapi_cuda_HtoD_stream());
  kaapi_cuda_task_body_t body = (kaapi_cuda_task_body_t)kaapi_format_get_task_body_by_arch(fmt, KAAPI_PROC_TYPE_CUDA);
  kaapi_assert_debug(body != 0);  
  ((kaapi_cuda_task_body_t)body)(sp, kaapi_cuda_kernel_stream());
  cudaDeviceSynchronize();
  cudaStreamSynchronize(kaapi_cuda_kernel_stream());
  kaapi_cuda_ctx_pop();
 
  return 0;
}
